@@ -1,9 +1,10 @@
 // Copyright 2021-2023 Sebastian Ramacher
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-use std::fs::File;
-use std::io::{self, BufRead, BufReader};
-use std::path::PathBuf;
+use std::{
+    fs::File,
+    io::{self, BufRead, BufReader},
+};
 
 use anyhow::Result;
 use assorted_debian_utils::{
@@ -11,35 +12,27 @@ use assorted_debian_utils::{
     wb::{BinNMU, SourceSpecifier, WBCommandBuilder},
 };
 use async_trait::async_trait;
-use clap::Parser;
 use log::{debug, warn};
 
 use crate::{
+    cli::{BaseOptions, NMUListOptions},
     config::{self, CacheEntries},
     udd_bugs::{load_bugs_from_reader, UDDBugs},
     utils::execute_wb_commands,
-    AsyncCommand, BaseOptions, BinNMUsOptions, Downloads,
+    AsyncCommand, Downloads,
 };
 
-#[derive(Debug, Parser)]
-pub(crate) struct NMUTransitionOptions {
-    #[clap(flatten)]
-    binnmu_options: BinNMUsOptions,
-    /// Input file with a list of packages. If not specified, the list of packages will be read from the standard input.
-    input: Option<PathBuf>,
-}
-
 pub(crate) struct NMUTransition<'a> {
     cache: &'a config::Cache,
     base_options: &'a BaseOptions,
-    options: NMUTransitionOptions,
+    options: NMUListOptions,
 }
 
 impl<'a> NMUTransition<'a> {
     pub(crate) fn new(
         cache: &'a config::Cache,
         base_options: &'a BaseOptions,
-        options: NMUTransitionOptions,
+        options: NMUListOptions,
     ) -> Self {
         Self {
             cache,
@@ -137,8 +130,6 @@ impl AsyncCommand for NMUTransition<'_> {
 
 impl Downloads for NMUTransition<'_> {
     fn downloads(&self) -> Vec<CacheEntries> {
-        vec![CacheEntries::FTBFSBugs(
-            self.options.binnmu_options.suite.into(),
-        )]
+        vec![CacheEntries::FTBFSBugs(self.options.binnmu_options.suite)]
     }
 }
